==> apache-camel-3.0.0-src.zip: apache-camel-3.0.0/components/camel-jetty/src/test/java/org/apache/camel/component/jetty/HttpAcceptHeaderTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.jetty;

import org.apache.camel.builder.RouteBuilder;
import org.junit.Test;

/**
 * Test HTTP client sends Accept header in HTTP GET
 */
public class HttpAcceptHeaderTest extends BaseJettyTest {

    @Test
    public void testAccept() throws Exception {
        String out = template.requestBodyAndHeader("http://localhost:{{port}}/myaccept", null, "Accept", "application/myjson", String.class);
        assertEquals("You called me as GET and accepted: application/myjson", out);
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            public void configure() throws Exception {
                from("jetty:http://localhost:{{port}}/myaccept").transform().simple("You called me as ${header.CamelHttpMethod} and accepted: ${header.Accept}");
            }
        };
    }

}

==> apache-camel-3.4.5-src.zip: apache-camel-3.4.5/components/camel-jetty/src/test/java/org/apache/camel/component/jetty/HttpAcceptHeaderTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.jetty;

import org.apache.camel.builder.RouteBuilder;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;

/**
 * Test HTTP client sends Accept header in HTTP GET
 */
public class HttpAcceptHeaderTest extends BaseJettyTest {

    @Test
    public void testAccept() throws Exception {
        String out = template.requestBodyAndHeader("http://localhost:{{port}}/myaccept", null, "Accept", "application/myjson", String.class);
        assertEquals("You called me as GET and accepted: application/myjson", out);
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            public void configure() throws Exception {
                from("jetty:http://localhost:{{port}}/myaccept").transform().simple("You called me as ${header.CamelHttpMethod} and accepted: ${header.Accept}");
            }
        };
    }

}
